package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````T"5```````!``````````'"S````
M`````````$``.``+`$``&P`:``8````$````0`````````!``$```````$``
M0```````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"0```````J`)````````<`````````!P``````````0`````````!````
M!`````````````````!``````````$```````'@4````````>!0`````````
M$`````````$````%`````"``````````($`````````@0```````-3T`````
M```U/0`````````0`````````0````0`````8`````````!@0````````&!`
M``````"@1````````*!$`````````!`````````!````!@```/"M````````
M\+U```````#PO4```````!@$````````L!0`````````$`````````(````&
M`````*X`````````OD````````"^0```````\`$```````#P`0````````@`
M````````!`````0```#$`@```````,0"0```````Q`)```````!$````````
M`$0`````````!`````````!0Y71D!````("=````````@)U```````"`G4``
M`````/P`````````_``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``#PK0```````/"]0```````\+U````````0`@```````!`"`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!0````#````
M1TY5``@BXJK=_AI#-?+94Y9(K!;0'ENL!````!`````!````1TY5```````#
M`````@`````````4````.@````(````'````P`@0`%``"`HX!T@!"0@("#H`
M```[````/```````````````/0`````````^```````````````_````````
M``````!``````````$$```!"`````````$,```!$````V7%8'#GRBQRGW:-K
MR=6R<0N*$%=7I)N6Q8D%D$-%U>S%N9Q`A_F<@7KP2FN[XY)\````````````
M````````````````````Y````!(`````````````````````````5`$``!(`
M````````````````````````MP$``!(`````````````````````````C`$`
M`!(`````````````````````````O@$``!(`````````````````````````
M2@(``!(`````````````````````````TP$``!(`````````````````````
M````,@(``!(`````````````````````````*@(``!(`````````````````
M````````H@```!(`````````````````````````E`$``!(`````````````
M````````````WP```!(`````````````````````````]@$``!(`````````
M````````````````Z`$``!(`````````````````````````I@$``!(`````
M````````````````````0P(``!(`````````````````````````4P(``!(`
M````````````````````````L0```!(`````````````````````````A0``
M`!(`````````````````````````OP```!(`````````````````````````
M@0$``!(`````````````````````````G0$``!(`````````````````````
M````I`(``!(`````````````````````````Z0```!(`````````````````
M````````S`$``!(`````````````````````````3P$``!(`````````````
M````````````B`(``!(`````````````````````````@0(``!(`````````
M````````````````'0```!(``````````````````````````0```"``````
M````````````````````"@(``!(`````````````````````````_````!(`
M````````````````````````;0$``!(`````````````````````````]0``
M`!(`````````````````````````2@```!(`````````````````````````
MR@```!(`````````````````````````5@```!(`````````````````````
M````+P$``!(`````````````````````````+0```!(`````````````````
M````````$0(``!(`````````````````````````>@```!(`````````````
M````````````"P$``!(`````````````````````````Q`$``!(`````````
M````````````````2`$``!(`````````````````````````<@(``!(`````
M````````````````````6@(``!(`````````````````````````>@(``!(`
M````````````````````````X0$``!(`````````````````````````DP``
M`!(`````````````````````````<0```!(`````````````````````````
M'P(``!(`````````````````````````AP$``!(`````````````````````
M````90$``!(`````````````````````````_`$``!(`````````````````
M````````V@$``!(`````````````````````````[P$``!(`````````````
M````````````9`(``!(`````````````````````````YP(``!``&``(PD``
M````````````````/`(``!$`&`!@PD````````@`````````G`(``"$`&`!`
MPD````````@`````````'`$``!(```!P(D``````````````````$````!$`
M&``PPD````````$`````````/0$``!$`&``@PD````````0`````````FP(`
M`"$`&`!`PD````````@`````````X`(``!``%P`(PD``````````````````
MF@(``!$`&`!`PD````````@`````````.0```!(````0(T``````````````
M````80```!(```"@($``````````````````\P(``!``&`"@TD``````````
M`````````%]?9VUO;E]S=&%R=%]?`%!,7V1O7W5N9'5M<`!097)L7V=V7V9E
M=&-H<'8`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?;&]C:P!097)L7V=E=%]S
M=@!097)L7VYE=UA3`&)O;W1?1'EN84QO861E<@!P97)L7W)U;@!P97)L7W!A
M<G-E`%!E<FQ?<W9?<V5T<'8`4&5R;%]S=E]S971P=FX`<&5R;%]C;VYS=')U
M8W0`<&5R;%]D97-T<G5C=`!P97)L7V%L;&]C`%!E<FQ?8W)O86M?;F]C;VYT
M97AT`'!E<FQ?9G)E90!097)L7W-A9F5S>7-M86QL;V,`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]N97=84U]F;&%G<P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S
M>7-?=&5R;0!03%]T:')?:V5Y`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I
M;VX`;'-E96LV-`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&5X:70`<W1R
M;F-M<`!G971P=W5I9`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN
M:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S
M=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R
M;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`
M9V5T=6ED`')E861L:6YK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H
M:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E
M;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`&QI8G!E<FPN<V\N-2XS,@!L:6)P
M=&AR96%D+G-O+C``;&EB8RYS;RXV`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD
M`$=,24)#7S(N,BXU`$=,24)#7S(N,RXT`$=,24)#7S(N,30`1TQ)0D-?,BXS
M+C(`1TQ)0D-?,BXT``````(``P`"``(``@`"``(``@`"`````@````(``@`$
M``(``@`````````#``(`!0````(``P`"``(```````8````#``(`````````
M``````<```````(``P`"``(``@`"```````"``(``P`'``(``@`'``$``@`"
M``````````(``0`"```````!`````0`!`,8"```0````(````'4::0D```,`
M^`(````````!``4`U@(``!``````````=!EI"0``!P`$`P``$````)21E@8`
M``8`$`,``!````!R&6D)```%`!L#```0````%&EI#0``!``G`P``$````'4:
M:0D```(`^`(```````#POT````````8````;``````````````#XOT``````
M``8````>```````````````@PD````````4````_```````````````PPD``
M``````4````^``````````````!`PD````````4```!"``````````````!@
MPD````````4````[```````````````8P$````````<````!````````````
M```@P$````````<````"```````````````HP$````````<````#````````
M```````PP$````````<````$```````````````XP$````````<````%````
M``````````!`P$````````<````&``````````````!(P$````````<````'
M``````````````!0P$````````<```!$``````````````!8P$````````<`
M```(``````````````!@P$````````<````)``````````````!HP$``````
M``<````*``````````````!PP$````````<````+``````````````!XP$``
M``````<````,``````````````"`P$````````<````-``````````````"(
MP$````````<````.``````````````"0P$````````<````/````````````
M``"8P$````````<````0``````````````"@P$````````<````1````````
M``````"HP$````````<````2``````````````"PP$````````<````3````
M``````````"XP$````````<````4``````````````#`P$````````<````5
M``````````````#(P$````````<````6``````````````#0P$````````<`
M```7``````````````#8P$````````<````8``````````````#@P$``````
M``<````9``````````````#HP$````````<````:``````````````#PP$``
M``````<````<``````````````#XP$````````<````=````````````````
MP4````````<````?```````````````(P4````````<````@````````````
M```0P4````````<````A```````````````8P4````````<````B````````
M```````@P4````````<````C```````````````HP4````````<````D````
M```````````PP4````````<````E```````````````XP4````````<````]
M``````````````!`P4````````<````F``````````````!(P4````````<`
M```G``````````````!0P4````````<````H``````````````!8P4``````
M``<````I``````````````!@P4````````<````J``````````````!HP4``
M``````<````K``````````````!PP4````````<````L``````````````!X
MP4````````<````M``````````````"`P4````````<````N````````````
M``"(P4````````<```!#``````````````"0P4````````<````O````````
M``````"8P4````````<````P``````````````"@P4````````<````Q````
M``````````"HP4````````<````R``````````````"PP4````````<````S
M``````````````"XP4````````<````T``````````````#`P4````````<`
M```U``````````````#(P4````````<````V``````````````#0P4``````
M``<````W``````````````#8P4````````<````X``````````````#@P4``
M``````<````Y````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%[9\``$B%P'0"_]!(@\0(PP```````````/\UXI\``/\EY)\`
M``\?0`#_)>*?``!H`````.G@_____R7:GP``:`$```#IT/____\ETI\``&@"
M````Z<#_____)<J?``!H`P```.FP_____R7"GP``:`0```#IH/____\ENI\`
M`&@%````Z9#_____);*?``!H!@```.F`_____R6JGP``:`<```#I</____\E
MHI\``&@(````Z6#_____)9J?``!H"0```.E0_____R62GP``:`H```#I0/__
M__\EBI\``&@+````Z3#_____)8*?``!H#````.D@_____R5ZGP``:`T```#I
M$/____\E<I\``&@.````Z0#_____)6J?``!H#P```.GP_O___R5BGP``:!``
M``#IX/[___\E6I\``&@1````Z=#^____)5*?``!H$@```.G`_O___R5*GP``
M:!,```#IL/[___\E0I\``&@4````Z:#^____)3J?``!H%0```.F0_O___R4R
MGP``:!8```#I@/[___\E*I\``&@7````Z7#^____)2*?``!H&````.E@_O__
M_R4:GP``:!D```#I4/[___\E$I\``&@:````Z4#^____)0J?``!H&P```.DP
M_O___R4"GP``:!P```#I(/[___\E^IX``&@=````Z1#^____)?*>``!H'@``
M`.D`_O___R7JG@``:!\```#I\/W___\EXIX``&@@````Z>#]____)=J>``!H
M(0```.G0_?___R72G@``:"(```#IP/W___\ERIX``&@C````Z;#]____)<*>
M``!H)````.F@_?___R6ZG@``:"4```#ID/W___\ELIX``&@F````Z8#]____
M):J>``!H)P```.EP_?___R6BG@``:"@```#I8/W___\EFIX``&@I````Z5#]
M____)9*>``!H*@```.E`_?___R6*G@``:"L```#I,/W___\E@IX``&@L````
MZ2#]____)7J>``!H+0```.D0_?___R5RG@``:"X```#I`/W___\E:IX``&@O
M````Z?#\____)6*>``!H,````.G@_/___R5:G@``:#$```#IT/S___\E4IX`
M`&@R````Z<#\____)4J>``!H,P```.FP_/___R5"G@``:#0```#IH/S___\E
M.IX``&@U````Z9#\____)3*>``!H-@```.F`_/___R4JG@``:#<```#I</S_
M__\E(IX``&@X````Z6#\____)1J>``!H.0```.E0_/__051(@^PPB7PD'$B-
M?"0<2(ET)!!(C70D$$B)5"0(2(U4)`AD2(L$)2@```!(B40D*#'`Z`C^__^Z
M<")``+\0(T``2(G6Z`8Y``"`/0^>````=2_H2/W__TB)!6FN``!(B<=(A<`/
MA(4!``#HD/S__XL]VIT``.C5_?__QH#I"0```(L]R)T``.C#_?__BSV]G0``
M@(@Z!````NBQ_?__@(@Z!````8M$)!R->`1$C6`#2&/_2,'G`^@C_?__2(M,
M)!"+="0<28G!2(D%\*T``$B+`4G'00C,84``2<=!&,]A0`!)B0%(BP5#G0``
M28E!$(/^`0^.[````$B#P0B#Q@.X!````&8N#Q^$``````!(BSE(8]"#P`%(
M@\$(28D\T3G&=>M(8_9(P>8#2(L]E:T``$2)XD4QP$R)R4G'!#$`````OF`M
M0`#HDOW__T&)Q(7`=$U(BSULK0``Z!_\__\QP$B-="0DOZ-@0`#H;@$``$B%
MP'0\2(L]2JT``.B=^___Z"C]__](BT0D*&1(*P0E*````'5B2(/$,$2)X$%<
MPTB+/1^M``#HTOW__T&)Q.NB2(L]_JP``$B%_W0'Z,P;``#KL;]:8$``2(UT
M)"3H"P$``$B)!=RL``!(B<=(A<!TD^O9OB````#I//___[\!````Z*;]___H
M4?O__Y`Q[4F)T5Y(B>)(@^3P4%1)Q\`074``2,?!L%Q``$C'Q]`C0`#_%?:9
M``#T#Q]$``"X",)``$@]",)``'03N`````!(A<!T";\(PD``_^!FD,-F9BX/
M'X0```````\?0`"^",)``$B![@C"0`!(B?!(P>X_2,'X`T@!QDC1_G01N```
M``!(A<!T![\(PD``_^##9F8N#Q^$```````/'T``@#WQFP```'4754B)Y>A^
M____Q@7?FP```5W##Q]$``##9F8N#Q^$```````/'T``ZXYF+@\?A```````
M#Q]``$%7059!54%455-(@^P(2(7_#X2Q````3(LM<IL``$V%[0^$H0````^V
M!TF)_TB)]83`=`0\/75813'V38ME`$V%Y'0R36/V3(GK9@\?1```3(GR3(G^
M3(GGZ%+Y__^%P'4'0X`\-#UT1TR+8PA(@\,(387D==I(@\0(3(G@6UU!7$%=
M05Y!7\,/'X0``````$F)_D$/MD8!28/&`83`=`0\/77O12G^ZY(/'X``````
M3"GK3XUD-`%(P?L#B5T`Z[4/'X``````13'DZZD/'P!!54%455-(@>RH````
M9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G]=2M(BX0DF````&1(*P0E
M*`````^%(P$``$B!Q*@```!;74%<05W#9@\?1```Z./X__])B<1(A<!TR$R)
MY^@3^___2(7`#X2R````@'@3+DB-6!-U$(![`0!TWV8N#Q^$``````"`>!,N
M#X2F````2(GOZ.[X__](B=])B<7HX_C__T&-?`4"2&/_Z/;Y__])B=E)B>BY
M!&!``$F)Q4B)Q[X!````,<!(Q\+_____Z&+[__^_`0```$B)XDR)[NA"^/__
M3(GO@_C_=!"+1"08)0#P```]`$```'1:Z,7W__],B>_HG??__TR)Y^AE^O__
M2(7`#X52____#Q]``$R)Y^C@^/__2(GOZ$CX___I\/[__P\?`(![`2X/A5#_
M__^`>P(`#X01____Z4'___\/'X``````Z)O^___KI.@T^/__#Q]``%5(B?Y(
MB?V_`0```$B![*````!D2(L$)2@```!(B80DF````#'`2(GBZ$+Z__^%P'4V
MBU0D&('B`/```('Z`$```'0(@?H`H```=1Z^`@```$B)[^C7^?__A<`/E,`/
MML#K!P\?1```,<!(BXPDF````&1(*PPE*````'4)2('$H````%W#Z*7W__\/
M'T0``%5(B?WHA_?__TB-5`7_2#G5<A;IA0````\?A```````2(/J`4@YU70E
M@#HO=/)(.=5S:DB#Z@%(.=5T$@\?0`"`.B]T($B#Z@%(.=5U\H!]`"]T5+\,
M8$``7>G!^?__D(`Z+W4)2(/J`4@YU7+R2"GJ,<!(C4H"2('Y`!```'<;2(/"
M`;D`$```2(GNOX#"0`#HBOC__[B`PD``7<-(.=5UP^NJ#Q]``+\*8$``7>EM
M^?__9F8N#Q^$``````!FD$%6NO\/``!!54%428GT54B)_;\.8$``2('L&!``
M`&1(BP0E*````$B)A"0($```,<!(B>;H!_;__X7`?G.-4/]$BS69EP``3&/J
M0H`\+`!U5X72=&),B>J^+P```$B)Y^@;]___2(7`=$U$B??H;O?__TR)Z4B)
MXDB)[DB)Q^A]^/__2(N$)`@0``!D2"L$)2@```!U.4B!Q!@0``!=05Q!74%>
MPP\?`$QCZ.NH#Q\`1(LU*9<``$2)]^@A]___3(GB2(GN2(G'Z%/V___KM.@,
M]O__9F8N#Q^$``````"005=!5D%505152(GU4TB)^TB#[!AD2(L$)2@```!(
MB40D"#'`,<"`/CT/E,!(`<5(B>_HN?7__TB-="0$2(G?28G$,<#H1_O__TB%
MP`^$!@$``$B)QTF)Q>B3]?__23G$#X;2````3&-T)`1)P>8##[8#A,`/A)X!
M```\/0^$E@$``$B)V`\?``^V4`%(@\`!A-)T!8#Z/77O2"G82)A*C7P@`DP#
M-7:6``#H8?;__TF)!DB%P'1:2(L%8I8``$AC5"0$2(U+`4B+%-`/M@.(`H3`
M="$\/74,ZQMF#Q]$``"$P'01#[8!2(/"`4B#P0&(`CP]=>O&`CTQP&8/'T0`
M``^V3`4`B$P"`4B#P`&$R77O2(M$)`AD2"L$)2@````/A0<!``!(@\086UU!
M7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(5`4`2(/``832=>[KO0\?0`!,
MBSW!E0``28,_``^$M@```$R)^$4Q[9!(@\`(1(GJ08/%`4B#.`!U[XUR`TAC
M]DC!Y@.+!<^E``"%P'5;QP7!I0```0```$B)]^AI]?__2(7`#X1A____36/U
M3(G^2(G'2<'F`TR)\N@+]O__2(D%5)4``$B)P4&-10%(F$C'!,$`````1(EL
M)`3IB/[__V8/'X0``````$R)_^BX]?__2(D%(94``$B)P4B%P`^$!O___TUC
M]4G!Y@/KNP\?0``QP.E__O__OA````!%,>WI7____^C/\___9F8N#Q^$````
M```/'T``2(/L"(L]MI0``.BQ]/__BSVKE```Z*;T__^Y2)U``+J@($``OAU@
M0`!(B<?HS_3__XL]B90``.B$]/__0;BI84``13')NM`^0`!(B<=,B<&^.6!`
M`$B#Q`CI`O7__V:02(/L"(L]5I0``.A1]/__N4B=0`"ZH"!``+X=8$``2(G'
M2(/$".EV]/__9@\?1```4TB!["`@``!D2(L$)2@```!(B80D&"```#'`Z(#R
M__]!N1E@0`"Y3F!``$B)YT&)P+H!$```O@$````QP.B.]?__N@`0``!(C;0D
M$!```$B)Y^@Y\O__13'`A<!X,XUX`4B)PTAC_^C4\___28G`2(7`=!U(8]M(
MC;0D$!```$B)QTB)VNB&\___Q@08`$F)P$B+A"08(```9$@K!"4H````=0Q(
M@<0@(```3(G`6\/H>_+__V9F+@\?A```````Z3O___]F9BX/'X0``````$%5
M28GU05152(G]OUI@0`!32('LN!```&1(BP0E*````$B)A"2H$```,<!(C70D
M#.B[]___OB\```!(B>](B</H._+__TB%P'0^,<!(B>Z_8V!``.@'_/__2(GH
M2(N<)*@0``!D2"L<)2@````/A7<!``!(@<2X$```6UU!7$%=PP\?@`````!(
MB>_HP/'__TR)[[YP8$``08G$Z-#S__])B<4/'T0``$V%[72=08!]```/A,@`
M``!(A=MT$TR)[DB)W^A8\O__A<`/A)P```!,B>_H>/'__XU0_XG!2&/"3`'H
M@#@O=1L/'X0``````(G1@^H!Q@``2&/"3`'H@#@O=.U"C40A`3W_#P``#X\W
M____2(/L"+ED84``38GH,<!50;D,8$``N@`0``"^`0```$B-O"2P````Z,'S
M__](C50D(+\!````2(VT)+````#HFO#__UI9A<!U$(M$)"@E`/```#T`@```
M=$2^<&!``#'_Z/CR__])B<7I*/___TB%VW0%@#LN=!9!O0I@0`"Y`0```.EI
M____9@\?1```@'L!`'3&Z^(/'X0``````+X!````2(V\)*````#HGO+__X7`
M=:9(C;0DH````+]C8$``Z(CZ__](C;PDH````.C[\O__Z7+^___H<?#__Y`/
MM@=)B?B$P'079@\?1```2(/'`3PO#[8'3`]$QX3`=>],B<##9F8N#Q^$````
M``!(A?]T"X`_`'0&Z9'X__^0OPI@0`#IIO+__V8/'T0``$B#[$AF#V\%5&P`
M`&1(BP0E*````$B)1"0X,<`QP`\11"009@]O!45L``!FB40D,`\11"0@#Q\`
M,<!(C70D#+]R8$``Z&?U__](A<!T.DAC5"0,2(L%YI```$B-!-!(BU`(2(D0
M2(72=,YF#Q]$``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B-="0,OWM@
M0`#H%_7__TB%P'0Z2&-4)`Q(BP66D```2(T$T$B+4`A(B1!(A=)TSF8/'T0`
M`$B+4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(UT)`R_@V!``.C']/__2(7`
M=#I(8U0D#$B+!4:0``!(C0302(M0"$B)$$B%TG3.9@\?1```2(M0$$B#P`A(
MB1!(A=)U\.NV9@\?1```,<!(C70D#+^,8$``Z'?T__](A<!T.DAC5"0,2(L%
M]H\``$B-!-!(BU`(2(D02(72=,YF#Q]$``!(BU`02(/`"$B)$$B%TG7PZ[9F
M#Q]$```QP$B-="0,OY-@0`#H)_3__TB%P'0Z2&-4)`Q(BP6FCP``2(T$T$B+
M4`A(B1!(A=)TSF8/'T0``$B+4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(UT
M)`R_HV!``.C7\___2(7`=#I(8U0D#$B+!5:/``!(C0302(M0"$B)$$B%TG3.
M9@\?1```2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```,<!(C70D#+]:8$``Z(?S
M__](A<!T.DAC5"0,2(L%!H\``$B-!-!(BU`(2(D02(72=,YF#Q]$``!(BU`0
M2(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B-="0,OZ]@0`#H-_/__TB%P'0Z2&-4
M)`Q(BP6VC@``2(T$T$B+4`A(B1!(A=)TSF8/'T0``$B+4!!(@\`(2(D02(72
M=?#KMF8/'T0``#'`2(UT)`R_N6!``.CG\O__2(7`=#I(8U0D#$B+!6:.``!(
MC0302(M0"$B)$$B%TG3.9@\?1```2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```
M,<!(C70D#+_#8$``Z)?R__](A<!T.DAC5"0,2(L%%HX``$B-!-!(BU`(2(D0
M2(72=,YF#Q]$``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B-="0,OV-@
M0`#H1_+__TB%P'0Z2&-4)`Q(BP7&C0``2(T$T$B+4`A(B1!(A=)TSF8/'T0`
M`$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-="0,O\U@0`#H^?'__TB)QDB%
MP'0,O[E@0``QP.A5]O__2(UT)`R_WF!``#'`Z-3Q__](B<9(A<!T#+_P8$``
M,<#H,/;__TB-="0,O_M@0``QP.BO\?__2(G&2(7`=#*_6F!``#'`Z`OV__\Q
MP+[*84``OY-@0`#H^O7__TB+1"0X9$@K!"4H````=4U(@\1(PTB-="0,OPMA
M0``QP.AD\?__2(G&2(7`=`Z_KV!``#'`Z,#U___KLTBX4$%27T-,14%(.40D
M(76B9H%\)"E./7692(UT)"OKT>B8Z___#Q^$``````!(@^P89$B+!"4H````
M2(E$)`B+!5",``"#^/]T&TB+="0(9$@K-"4H````=4!(@\08PV8/'T0``$B-
M="0$OZ]@0``QP.C7\/__2(G",<!(A=)T$@^V$H#Z,`^5P3'`A-(/E<`AR(D%
M_8L``.NPZ![K__]F9BX/'X0```````\?`$B#[`CH%^O__XG'Z,#J__](A<!T
M`TB+`$B#Q`C##Q\`05152(G]OR=A0`!32(/L$&1(BP0E*````$B)1"0(,<!(
MC70D!.A6\/__2(7`=`B`.`!(B<-U,4B+1"0(9$@K!"4H````#X6P````2(GN
M2(/$$+\G84``,<!;74%<Z8[T__]F#Q]$``!(B>Y(B<?H#>W__TB%P'0@2(M$
M)`AD2"L$)2@```!U<TB#Q!!;74%<PP\?@`````!(B>_H0.K__TB)WTF)Q.@U
MZO__28U\!`+H2^O__TB#[`A)B>BY9&%``%-(Q\+_____2(G'28G$0;EP8$``
MO@$````QP.BO[/__6%I(BT0D"&1(*P0E*````'4(3(GFZ5/____H\.G__T%7
M059!54F)_;]:8$``05154TB!['B!``!D2(L$)2@```!(B80D:($``#'`2(UT
M)`Q(QT0D$$-A0`!(QT0D&`I@0`!(QT0D(`````!(QT0D6.E@0`!(QT0D8$AA
M0`!(QT0D:`9A0`!(QT0D<%!A0`!(QT0D>`````!(QT0D.%1A0`!(QT0D0```
M``#H\.[__TB%P'0,@#@`2(G%#X5O!```Z%KI__^)Q^@#Z?__2(7`#X2Z`P``
M2(L82(7;#X2N`P``2(G?Z!;I__](C7P``>@LZO__1`^V`TF)Q$6$P'0T3(GE
M#Q]$``!(B>^Y76%``+X!````,<!(Q\+_____2(/#`4B#Q0+HA>O__T0/M@-%
MA,!UU$B-7"18O_!@0`#K$$B+.TB#PPA(A?\/A#`!``!(C70D##'`Z$3N__](
MB<5(A<!TW(`X`'372(G'Z&_P__^%P'3+2(GOZ!/K__](B<5(A<`/A/<````/
M'X``````2(GOZ&CH__],B>=(B</H7>C__T2-O`,$!```36/_3(G_Z&KI__]!
M5$F)Z$&Y#&!``&AK84``2(G'28G&N6)A0`!(Q\+_____O@$````QP.C,ZO__
M3(GWOL`!``#H;^?__U]!6(/X_W42Z#+G__]$BPA!@_D1#X7Y`@``2(V4)(``
M``!,B?:_`0```.@PZO__B<.%P`^$M@```$F+30!(BST;B0``38GP,<"Z&&)`
M`+X!````13'DZ#3J__](BX0D:($``&1(*P0E*`````^%2P4``$B!Q'B!``!,
MB>!;74%<05U!7D%?PP\?A```````2(ML)!`QV^L4#Q^``````$ACPTB+;,00
M2(7M=#N`?0``=#5(B>^#PP'H,N___X7`=-Y(B>_HUNG__TB)Q4B%P`^%RO[_
M_TACPTB+;,002(7M=<H/'T0``#'MZ;'^__^0BX0DF````"4`\```/0!````/
MA3/___^+K"2<````Z!WG__\YQ0^%'____XN$))@````E_P$``#W``0``#X4(
M____3(G_Z/;G__^_,F%``$B-="0,28G$,<#H8NS__TB)QTB%P`^$)@(``.A!
MZ?__28M]`$B)QNA5]/__2(G%2(7`#X0)`@``2(GOZ)'F__^#^`-^/$ACT+]P
M84``N04```!(C705_/.F#Y?"@-H`A-)U'H/X!`^$80,``(/H!4B8@'P%`"\/
MA%$#```/'T0``(L%,H<``(/X_P^$`0,``(7`#X2\`0``OLIA0`"_KV!``#'`
MZ#CP___HH^7__VBI84``38GP3(GG4$C'PO____]!N0Q@0``QP+F)84``O@$`
M``#HJ>C__UA:ZTH/'T0``.@;Y?__@S@1=4WH8>7__X/#`4B#[`A-B?!HJ6%`
M`$&Y#&!``$R)Y[F784``4TC'PO____^^`0```%`QP.A?Z/__2(/$(+[``0``
M3(GGZ/[D__^#^/]TJ4R)]^BQY/__3(GFOUI@0``QP.B2[___3(GGZ)KZ___I
MP?W__P\?1```,>V_-V%``.L4#Q^``````$ACQ4B+?,0P2(7_=#I(C70D##'`
M@\4!Z.3J__](A<!TWX`X`'3:2(G'Z,+G__](B<-(A<`/A0C\__](8\5(BWS$
M,$B%_W7&OPT```"[/&%``.@JYO__0;A3````28G$Z?S[__])BTT`2(L]088`
M`$V)\#'`NMAA0`"^`0```$4QY.A:Y___Z2']__\/'T0``$B)Q^CH^?__2(N$
M)&B!``!D2"L$)2@````/A5\"``!(@<1X@0``2(GO6UU!7$%=05Y!7^DHY___
M#Q^$``````!)BVT`Z>[]___'!66%````````2(GO,?8QP.A!YO__B<6%P`^$
M+O[__[H"````2,?&[O___XG'Z,3F__^Z!@```$B-M"1@`0``B>_H`.7__X"\
M)&`!````=0Z`O"1A`0``0P^$9`$``#'2,?:)[^B-YO__,<#HMAL``$F)Q>L3
MD(G"2(VT)&`!``!,B>_H_AL``+H`@```2(VT)&`!``")[^BJY/__A<!_UHGO
M3(V\)#`!``!(C:PD$`$``.@_Y/__3(GN2(V\)!`!``!,B?OH7!T``$R-K"18
M`0``#Q]``$0/MD4`2(G?N5UA0``QP$C'PO____^^`0```$B#PP)(@\4!Z#CF
M__]).=UUT\:$)%@!````:*EA0`!!5[EZ84``O@$```!-B?!,B>=!N0Q@0`!(
MQ\+_____,<#H`.;__UE>Z;#]__]F#Q^$```````QP$B-="0,OZ]@0`#HS^C_
M_TB%P`^$G_[__P^V`(3`#X24_O__/#`/A(S^___'!?&#```!````Z<O\__]-
MBVT(387M#X2G_/__3(GOZ._B__](@_@##X:5_/__28UT!?R_=6%``+D%````
M\Z8/E\`<`(3`20]$[>ET_/__@+PD8@$``$$/A8[^__^`O"1C`0``0P^%@/[_
M_X"\)&0!``!(#X5R_O__@+PD90$``$4/A63^__^Z`@```$C'QL;___^)[^CI
MY/__2(VT)&`!``"Z*0```(GOZ"7C__]HJ6%``$B-A"1H`0``4.G>_O__Z%WB
M__]F9BX/'X0``````&:0055!5$B#[!B+/4*#``!D2(L$)2@```!(B40D"#'`
MZ"WC__^+/2>#``!)B<3H'^/__TB-="0$OY-@0`!!#[:4)+@```"(D+D````Q
MP.B/Y___2(7`=`F`.#$/A+$!```QP.C*\?__BSWD@@``Z-_B__^Y`P```+H!
M````OJAA0`!(B<?HF.+__TF)Q$B%P'0V2(M`$(L]MH(``$R+*.BNXO__NJIA
M0`!(B<=,B>[HWN'__TF+1"003(L@0?9$)`Y`#X6*`0``BSV$@@``Z'_B__^Y
M`P```+H!````OJ]A0`!(B<?H..+__TF)Q$B%P'0^2(UT)`2_8V!``#'`Z-_F
M__])B<5(A<`/A!,!``!)BT0D$(L].((``$R+(.@PXO__3(GJ2(G'3(GFZ&+A
M__^+/1R"``#H%^+__[H!````OK%A0`!(B<?H)>+__XL]_X$``$F)Q.CWX?__
M3(GFNL9A0`!(B<?H)^'__XL]X8$``.C<X?__2(UT)`2_6F!``,:`N0`````Q
MP.A4YO__2(D%)9(``$F)Q$B%P'1%OL`!``!,B>?H^-___XU0`8/Z`78)@_@1
M#X6R````2(M$)`AD2"L$)2@````/A;D```!(@\0805Q!7<-F+@\?A```````
M2(L]V9$``.AT]O__2(D%Q9$``$F)Q$B%P'6@OW!B0``QP.AYX?__9@\?A```
M````@'@!``^$3/[__^E`_O__D$B+!9F1``"+/2.!``!,BRA)BT0D$$R+(.@3
MX?__3(GN3(GGZ"CI___IX?[__P\?`(L]^H```.CUX/__3(GF2(G'Z%KA___I
M6_[__XG!2(L%3)$``$R)XK^88D``2(LP,<#H^N#__^C%W___#Q]$``!!5%5(
MB?U32(/L$&1(BP0E*````$B)1"0(,<!(A?\/A*P```"`/P`/A*,```#H[N?_
M_P^V$$B)PX32=!8/'T``2(/``8#Z+P^V$$@/1-B$TG7NBP5`@```2(7M00^5
MQ(/X_W1\A<`/E<!!(<1%A.1U'TB+1"0(9$@K!"4H````#X6:````2(/$$%M=
M05S#9I"`?0``=-N_:V%``+D$````2(G>\Z8/E\`<`(3`=<-(BT0D"&1(*P0E
M*````'5A2(/$$$B)[UM=05SI4N7__V:0OPI@0`#H9N'__^E3____D#'`2(UT
M)`2_KV!``.A?Y/__2(7`=`L/M@"$P'0$/#!U#\<%C7\```````#I8?___\<%
M?G\```$```#I3?___^B<WO__9BX/'X0``````&:005=,C4\X059!54%455-(
M@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)XDR-E"2`````28G09BX/'X0`
M`````$&+`4F+,4F#P!!)@\$(#\B)P$B)\4F)0/!(B?!(P>D@2,'H*$C![C@E
M`/\``$@)\$B)SDC!X0A(P>88@>$``/\`B?9("?!("<A)B4#X33G0=:Y(C;(`
M`@``#Q^``````$B+0FA(,T)`2(/""$@S0@A(,T+X2(T,`$C!Z!]("<B#X/](
MB4)X2#GR==5,BP],BU\02(MW($B+7QA,B<A,B<I(BV\(2,'J&TC!X`5("=`#
M!"2-E#"9>8):3(G82(MT)`A(,=A((>A(C;0SF7F"6D@QV$2-%`)(B>I(B>A(
MP>@"2,'B'DV)T$@)PDR)V$G!Z!N)T4@QR$PAR$PQV$@!\$R)UDC!Y@5,"<9$
MC30P3(G.3(G(2,'F'DC!Z`)-B?!("?!(BW0D$$G!Z!M(,<)!B<5,(=))C;0S
MF7F"6D@QRD@!\DR)]DC!Y@5,"<9$C00R3(G62<'J`DB+5"082,'F'DP)UDB-
ME!&9>8):3(G!2#'P08GT3"'P3#'H2,'I&T@!T$R)PDC!X@5("<I,B?%)P>X"
M2,'A'D2-%!!(B?!(BU0D($P)\4R)UD@QR$F-E!69>8):2,'N&T&)SDPAP$PQ
MX$@!T$R)TDC!X@5("?)$C2P03(G"2<'H`DB+1"0H2,'B'DR)[DP)PDF-A`29
M>8):2,'N&T@QT4&)T$PAT4PQ\4@!P4R)Z$C!X`5("?!$C20!3(G02<'J`DB+
M3"0P2,'@'DR)YDP)T$F-C`Z9>8):2#'"08G"3"'J3#'"2`'*3(GA2,'A!4C!
M[AM("?%,B>Y)P>T"2,'F'D2--`I(BU0D.$P)[DR)\4@Q\$F-E!"9>8):2,'I
M&T&)]4PAX$PQT$@!T$R)\DC!X@5("<I,B>%)P>P"2,'A'D2-!!!(B?!(BU0D
M0$P)X4R)QD@QR$F-E!*9>8):2,'N&T&)S$PA\$PQZ$@!T$R)PDC!X@5("?)$
MC1003(GR2<'N`DB+1"1(2,'B'DR)UDP)\DF-A`69>8):2,'N&T@QT4&)UDPA
MP4PQX4@!P4R)T$C!X`5("?!$C2P!3(G`2<'H`DB+3"102,'@'DR)[DP)P$F-
MC`R9>8):2,'N&T@QPD&)P$PATDPQ\D@!RDR)Z4C!X05("?%,B=9)P>H"2,'F
M'D2-)`I(BU0D6$P)UDR)X4@Q\$F-E!:9>8):2,'I&T&)\DPAZ$PQP$@!T$R)
MXDC!X@5("<I,B>E)P>T"2,'A'D2--!!(B?!(BU0D8$P)Z4R)]D@QR$F-E!"9
M>8):2,'N&T&)S4PAX$PQT$@!T$R)\DC!X@5("?)$C0003(GB2(M$)&A(P>(>
M2<'L`DR)QDP)XDF-A`*9>8):2,'N&T@QT4&)U$PA\4PQZ4@!P4R)P$C!X`5(
M"?!$C10!3(GP2<'N`DB+3"1P2,'@'DR)UDP)\$F-C`V9>8):2,'N&T@QPD&)
MQDPAPDPQXD@!RDR)T4C!X05("?%,B<9)P>@"2,'F'D2-+`I(BU0D>$P)QDR)
MZ4@Q\$F-E!29>8):2,'I&T&)\$PAT$PQ\$@!T$R)ZDC!X@5("<I,B=%)P>H"
M2,'A'D2-)!!(B?!(BY0D@````$P)T4R)YD@QR$F-E!:9>8):2,'N&T&)RDPA
MZ$PQP$@!T$R)XDC!X@5("?)$C3003(GJ2<'M`DB+A"2(````2,'B'DR)]DP)
MZDF-A`"9>8):2,'N&T@QT4&)U4PAX4PQT4@!P4R)\$C!X`5("?!$C00!3(G@
M2<'L`DB+C"20````2,'@'DP)X$F-C`J9>8):38G"2#'"2<'J&XG&3"'R3#'J
M2`'*3(G!2,'A!4P)T4V)\DG![@))P>(>B<E-"?)(`<I(BXPDF````$PQT$&)
MU$PAP$F-C`V9>8):38GE2#'P2<'M&T@!R$R)X4C!X05,">F)R4@!R$R)P4G!
MZ`)(P>$>08G%3`G!38G018G23`.4)*@```!),<A$,<),BX0DH````$Z-A`:A
MZ]EN3(GN20'03(GJ2,'N&TC!X@5("?*)TDD!T$R)XDG![`)(P>(>1(G&3`GB
M28G,B<E(`XPDL````$DQU$0QX$F)]$V-E`*AZ]EN2(GP2<'L&TC!X`5,">")
MP$D!PDR)Z$G![0)(P>`>18G43`GH28G5B=)),<5%,>A-B>5(`Y0DN````$Z-
MA`&AZ]EN3(GA2<'M&TC!X05,">F)R4P!P4F)\$C![@))P>`>08G-20GP2(G&
MB<!(`X0DP````$PQQD$Q\DJ-M!*AZ]EN3(GJ38GJ2<'J&TC!X@5,"=*)TD@!
M\DR)YDG![`)(P>8>08G23`GF38G$18G`3`.$),@```!),?1$,>%-B=1(C8P(
MH>O9;DR)T$G![!M(P>`%3`G@B<!(`<A,B>E)P>T"2,'A'D&)Q$P)Z4F)]8GV
M23'-1#'J38GE38V$$*'KV6Y,B>)(P>(%2<'M&T@#M"30````3`GJB=))`=!,
MB=))P>H"2,'B'D6)Q4P)TDF)RHG)2`.,)-@```!),=)$,=!-B>I(C;0&H>O9
M;DR)Z$G!ZAM(P>`%3`G0B<!(`<9,B>!)P>P"2,'@'D&)\DP)X$F)U(G22`.4
M).````!),<1%,>!-B=1.C80!H>O9;DR)T4G![!M(P>$%3`GAB<E,`<%-B>A)
MP>T"2<'@'D&)S$T)Z$F)Q8G`33'%1#'N38GE2(VT,J'KV6Y,B>))P>T;2,'B
M!4P)ZHG22`'R3(G62<'J`D@#A"3H````2,'F'D&)U4P)UDV)PD6)P$P#A"3P
M````23'R1#'138GJ2(V,"*'KV6Y,B>A)P>H;2,'@!4P)T(G`2`'(3(GA2<'L
M`DC!X1Y!B<),">%)B?2)]D@#M"3X````23',1#'B38G438V$$*'KV6Y,B=))
MP>P;2,'B!4P)XHG220'03(GJ2<'M`DC!XAY%B<1,">I)B<V)R4DQU40QZ$V)
MY4B-M`:AZ]EN3(G@2<'M&TC!X`5,">B)P$@!QDR)T$C!X!Y)P>H"08GU2`.,
M)``!``!,"=!)B=*)TD@#E"0(`0``23'"13'038GJ3HV$`:'KV6Y,B>E)P>H;
M2,'A!4P)T8G)3`'!38G@2<'L`DG!X!Y!B<I-">!)B<2)P$@#A"00`0``33'$
M1#'F38G42(VT,J'KV6Y,B=))P>P;2,'B!4P)XHG22`'R3(GN2<'M`DC!YAY!
MB=1,">Y-B<5%B<!),?5$,>E-B>5(C8P(H>O9;DR)X$G![1M(P>`%3`GHB<!(
M`<A,B=%)P>H"2,'A'D&)Q4P)T4F)\DP#A"08`0``B?9),<I(`[0D(`$``$0Q
MTDV-M!"AZ]EN3(GJ38GH2<'H&TC!X@5,"<))B<B)R4@#C"0H`0``B=))`=9,
MB>))P>P"2,'B'D6)\DP)XDDQT$0QP$R-I`:AZ]EN3(G03(G62,'N&TC!X`5(
M"?!(B=:)TD@#E"0P`0``B<!)`<1,B>A)P>T"2,'@'D6)X$P)Z$@QQD$Q]DR)
MQDZ-K#&AZ]EN3(G!2,'N&TC!X05("?&)R4D!S4R)T4G!Z@)(P>$>1(GN3`G1
M28G"B<!),<I%,=1(`X0D.`$``$Z-E"*AZ]EN2(GR28GT2<'L&TC!X@5,">)-
MB<1)P>@"2<'D'D$!TDT)Q$F)R(G)33'@1(GB13'%3HV$**'KV6Y,B=!-B=5)
MP>T;2,'@!4P)Z$R+K"1``0``18TT`$F)\$C![@),B>!)P>`>20GP1(G&3`G`
M3"'022'T20G$N-R\&X])`<5,`>E-B?5,`>%-B?1)P>T;2<'D!4T)[$$!S$R)
MT4G!Z@)(P>$>3`G120G(28G-08G*32'P22'U30GH3(NL)$@!``!)`<5,`>I-
MB>5)`=!,B>))P>T;2,'B!4P)ZD6-+!!,B?))P>X"2,'B'DP)\DF)SD&)T$D)
MUDTAYDPAP4P)\4R+M"10`0``20'&3`'V38GN2`'Q3(GN2<'N&TC!Y@5,"?9$
MC30Q3(GF2<'L`DC!YAY,">9("?))B?2)\4TAQ$PAZDP)XDR+I"18`0``20'$
M30'B38GT3`'238GR2<'B!4G![!M-">)&C20238GJ2<'M`DG!XAY-">I)B?5$
MB=)-"=5-(?5((=9,">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)X$G![1M)P>`%
M30GH1HTL!DV)\$G![@))P>`>30GP30G"38G&1(G&22'632'B30GR3(NT)&@!
M``!)`<9,`?%-B>Y)`<I,B>E)P>X;2,'A!4P)\46--`I,B>%)P>P"2,'A'DP)
MX4V)Q$D)S$&)RDTA[$TAT$T)X$R+I"1P`0``20'$3`'B38GT20'03(GR2<'L
M&TC!X@5,">)%C2003(GJ2<'M`DC!XAY,">I("=%)B=5!B=!-(=5,(?%,">E,
MBZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL,4R)]DG![@)(
MP>8>3`GV28G6B?%)"?9-(>9((<I,"?),B[0D@`$``$D!QDT!\DV)[DP!TDV)
MZDG![AM)P>(%30GR1HTT$DV)XDG![`))P>(>30GB3`G638G41(G222',3"'N
M3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$:-)`9-B>A)
MP>T"2<'@'DT)Z$V)U42)QDT)Q4TA]4DA\DT)ZDR+K"20`0``20'%3`'I38GE
M20'*3(GA2<'M&TC!X05,">E%C2P*3(GQ2<'N`DC!X1Y,"?%)"<A)B<Y!B<I)
M(?9-(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%3`GR18TT
M$$R)XDG![`)(P>(>3`GB28G,08G020G432'L3"'!3`GA3(ND)*`!``!)`<1,
M`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-)#%,B>Y)P>T"2,'F'DP)[D@)\DF)
M]8GQ32'%3"'R3`GJ3(NL)*@!``!)`<5-`>I-B>5,`=)-B>))P>T;2<'B!4T)
MZD:-+!)-B?))P>X"2<'B'DT)\DF)]D2)TDT)UDTAYD@AUDP)]DR+M"2P`0``
M20'&30'P38GN3`'&38GH2<'N&TG!X`5-"?!&C30&38G@2<'L`DG!X!Y-">!-
M"<)-B<1$B<9)(=1-(>I-">),BZ0DN`$``$D!Q$P!X4V)]$D!RDR)\4G![!M(
MP>$%3`GA18TD"DR)Z4C!X1Y)P>T"3`GI38G%08G*20G-32'U32'030GH3(NL
M),`!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD6-+!!,B?))P>X"2,'B
M'DP)\D@)T4F)T$&)UTTAT$PAX4P)P4R+A"3(`0``20'`3`'&38GH2`'Q3(GN
M2<'H&TC!Y@5,"<9$C00Q3(GF2<'L`DB)T4C!YAY,">9!B?1("?%,(>E,(>)(
M"<I(BXPDT`$``$@!P4@#A"38`0``20'*3(G!20''3`'238G"2,'A!4G!ZAM,
M"=&)R4@!RDR)Z4G![0)(P>$>08G23`GI3(G02`G.28G-2,'@!4&)SDTAY4PA
MQDP)[DV)U4G![1M,`?Y,">B)P$@!QDR)P$G!Z`)(P>`>08GU20G`N-;!8LI,
M,<$QRDB+C"3@`0``2`'!3`'A38GL2`'13(GJ2<'L&TC!X@5,">*)TD@!T4R)
MTDG!Z@)(P>(>08G,20G23(G"18G`3#'2,=9(BY0DZ`$``$@!PDD!UDR)XDP!
M]DV)YDC!X@5)P>X;3`GRB=),C3063(GJ2<'M`DR)UDC!XAY%B?=%B=))"=5(
MBY0D\`$``$PQ[D@!PC'Q3(G^3`'"2,'N&T@!T4R)^DC!X@5("?)(B[0D^`$`
M`(G22`'13(GB2`'&2<'L`DC!XAY,`=9-B>I!B<A,">)-B<1%B>U),=)%,=9.
MC10V3(G&2,'F!4G![!M,">:)]DD!\DR)_DG![P)(P>8>18G420GW2(NT)``"
M``!(`<9,`>Y)B=6)TDTQ_40QZ4R-+`Y,B>%,B>9(P>X;2,'A!4@)\4R)QDG!
MZ`*)R4C!YAY)`<U(BXPD"`(``$P)QDV)^$DQ\$6)[D6)_T@!P44QPD@!RDR)
M\4Z-!!),B?)(P>D;2,'B!4@)RDB)\8GVB=))`=!,B>))P>P"2,'B'D6)PDD)
MU$B+E"00`@``3#'A2`'"03'-3(G13`'Z20'53(G22,'I&TC!X@5("<I,B?%)
MP>X"B=)(P>$>20'52(N4)!@"``!,"?%%B>](`<)(`?),B>9%B>1(,<Y!,?!,
MB?Y)`=!,B?I(P>X;2,'B!4@)\HG220'03(G22<'J`DC!XAY%B<9)"=)(BY0D
M(`(``$R)]DC![AM(`<),`>))B<R)R4TQU$4QY4Z-)"I,B?)(P>(%2`GR2(NT
M)"@"``")TDD!U$R)^D@!QDG![P)(P>(>18GE3`GZ2`'Q3(G618G22#'603'P
M3(GN20'(3(GI2,'N&TC!X05("?&)R4D!R$R)\4G![@)(P>$>18G'20G.2(N,
M)#`"``!,B?Y(P>X;2`'!3`'128G2B=)-,?)%,=1.C10A3(GY2,'A!4@)\4R)
M[DG![0*)R4C!YAY)`<I(BXPD.`(``$P)[D6)U$@!P4@!RDR)\46)]D@Q\4$Q
MR$R)X4D!T$R)XDC!Z1M(P>(%2`G*2(GQB?:)TDD!T$R)^DC!XAY)P>\"18G%
M20G72(N4)$`"``!,,?E(`<)!,<I,B>E,`?)(P>D;20'23(GJ2,'B!4@)RDR)
MX4G![`*)TDC!X1Y)`=)(BY0D2`(``$P)X46)_$6)UD@!PD@!\DR)_D@QSD$Q
M\$J--`),B?)-B?!)P>@;2,'B!4P)PHG22`'63(GJ2<'M`DC!XAY!B?!)"=5(
MBY0D4`(``$@!PDP!XDF)S(G)33'L13'B3HTD$DR)PDV)PDG!ZAM(P>(%3`G2
MB=))`=1,B?))P>X"2,'B'D6)XDP)\DR+M"18`@``20'&3`'Q38GN18GM23'6
M1#'V38G62`'.3(G12<'N&TC!X05,"?&)R4@!SDR)P4G!Z`)(P>$>08GV20G(
M2(N,)&`"``!(`<%)`<U(B=&)TDPQP4$QS$N-3"4`38GT38GU2<'M&TG!Y`5-
M">Q-B=5)P>H"2<'E'D6)Y$T)ZDR+K"1H`@``3`'A08G,20'%3`'J38G%18G`
M33'51#'N3(TL,DR)XDR)YDC!X@5(P>X;2`GRB=))`=5,B?))P>X"2,'B'D2)
M[DD)UDB+E"1P`@``2`'"2`.$)'@"``!,`<)-B=!-,?!$,<%)B?!(`<I(B?%)
MP>@;2,'A!4P)P46)T`'13(GB2<'L`DC!XAY)"=1*C10(2(G(20'03(GR2,'@
M!40!XTPQXDB)7QA!,=5+C10H28G(`>E)P>@;2(E/"$P)P`'02(D'2(GP2,'N
M`DC!X!Y("<9!`?-$`W<@3(E?$$R)=R!(BX0DB`(``&1(*P0E*````'422('$
MF`(``%M=05Q!74%>05_#Z'3(__\/'T``2(/L"+^`````Z'+)__^ZB:O-[[G^
MW+J8OO#ATL-(QP`!(T5G2(E0"$B)2!!(QT`8=E0R$$B)<"!(QT`H`````$C'
M0#``````QT!X`````$B#Q`C#9F8N#Q^$``````"005=(8\)!5DF)QD%5051)
MB?Q52(UO.%-(B?-(@^P(2(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!Z!U(`=!(
MB4<P2&-'>(7`#X7M````08/^/P^.*P$``$&#[D!%B?=!P>\&18UO`4G!Y09)
M`=T/'T0``/,/;P-,B>=(@\-`#Q%%`/,/;TO0#Q%-$/,/;U/@#Q%5(/,/;UOP
M#Q%=,.CAZ/__3#GK=<Q!P><&12G^26/&2(/X"')<28M5`$F)5"0X28M4!?A(
MB50%^$B-50A(@^+X2"G522GM2`'%2(/E^$B#_0AR&$B#Y?@QP$F+3`4`2(D,
M`DB#P`A(.>AR[D6)="1X2(/$"%M=05Q!74%>05_#9I"H!'5T2(7`=.%!#[95
M`$&(5"0XJ`)TTT$/MU0%_F:)5`7^Z\8/'T``0;U`````2(U\!0!(B=Y!*<5%
M.>Y%#T[N36/]3(GZZ)7'__]!BT0D>$0!Z$&)1"1X@_A`=9),B>=%*>Y,`?OH
M!>C__^G+_O__28G=Z2/___]!BU4`08E4)#A!BU0%_(E4!?SI6____Y!!5DR-
M=CA!54%454B)]5-(BT8H2(G[1(MF*$2+;C!(P>@#@^`_00_,00_-C4@!2)C&
M1`8X@$ACP4P!\(/Y.`^.)`$``+Y`````*<YT#S'2B=&#P@'&!`@`.?)R\TB)
M[^A\Y___9@_OP`\113A)QT8P`````$$/$48000\11B!$B6UP2(GO1(EE=.A2
MY___2(M%`$B)[TC!Z!B(`TB+10!(P>@0B$,!2(M%`$C!Z`B(0P)(BT4`B$,#
M2(M%"$C!Z!B(0P1(BT4(2,'H$(A#!4B+10A(P>@(B$,&2(M%"(A#!TB+11!(
MP>@8B$,(2(M%$$C!Z!"(0PE(BT402,'H"(A#"DB+11"(0PM(BT482,'H&(A#
M#$B+11A(P>@0B$,-2(M%&$C!Z`B(0PY(BT48B$,/2(M%($C!Z!B(0Q!(BT4@
M2,'H$(A#$4B+12!(P>@(B$,22(M%((A#$UM=05Q!74%>Z1O$__\/'P"Z.```
M`#'_*<J#^@AR2HG12,<``````$C'1`CX`````$B-2`A(@^'X2"G(`<*#XOB#
M^@@/@MW^__^#XO@QP(G&@\`(2(D\,3G0<O/IQO[__P\?A```````]L($=2.%
MT@^$L?[__\8``/;"`@^$I?[__S')9HE,$/[IF?[__P\?`,<``````,=$$/P`
M````Z8/^__\/'T0``$%73(T]-V$``$%628G6055)B?5!5$&)_%5(C2TH80``
M4TPI_4B#[`CH(\/__TC!_0-T&S';#Q\`3(GR3(GN1(GG0?\4WTB#PP%(.=UU
MZDB#Q`A;74%<05U!7D%?PP\?`,-F+@\?A```````#Q]$``!(BPW)9```Z73$
M__](@^P(2(/$",,`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"X`+P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`$Q$7TQ)0E)!4EE?4$%4
M2`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`
M)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E
M;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R
M.CI615)324].`#$N,#4Q`"UE`"TM`````````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@
M6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@
M)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@
M)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N
M86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A
M<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD
M;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU
M;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L
M<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL
M92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P
M*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U
M9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5
M;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY
M("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D
M:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN
M<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA
M;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D
M92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L
M("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ
M3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO
M=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%
M(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O
M;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D
M>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`[
M"FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]
M"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI3
M2$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F
M:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M
M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E
M<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D
M9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N
M86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC
M;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`````'!E<FQX<VDN8P``
M`````````````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M`1L#._P````>````H(+__T@!``!0AO__C`4``%"(__\8`0``,(G__W`!````
MBO__O`$``'"+___X`0```(S__QP"``#`C/__1`(``*"-__^``@``X(___\P"
M``!`D/__Y`(``'"0___\`@``,)'__R`#``!`D?__-`,``#"3__^$`P``8)/_
M_Y@#``"`D___K`,``!"8___(`P``D)C__^0#``"PF/___`,``+"9__],!```
M4*'__QP%``#@H___2`4``!"E__^P!0``,+O__P`&``"0N___&`8``#"]__]D
M!@``,+___Z@&``"0O___\`8``*"___\(!P```````!0``````````7I2``%X
M$`$;#`<(D`$'$!0````<````,(?__RL``````````````!0``````````7I2
M``%X$`$;#`<(D`$``"0````<````4('__[`#````#A!&#AA*#PMW"(``/QH[
M*C,D(@````!(````1````+B'___-`````$(.$(\"0@X8C@-"#B"-!$(.*(P%
M00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(20L`.````)``
M```\B/__;`$```!"#A"-`D(.&(P#00X@A@1!#BB#!4<.T`%^"@XH00X@00X8
M0@X00@X(1PL`(````,P```!PB?__BP````!!#A"&`E(.L`$"<0H.$$$."$$+
M)````/````#<B?__LP````!!#A"&`@)9"@X(1@M\"@X(00M1#@@``#@````8
M`0``=(K__]0`````0@X0C@)'#AB-`T(.((P$1`XHA@5/#L`@`G\*#BA!#B!"
M#AA"#A!"#@A$"T@```!4`0``&(O__S$"````0@X0CP)"#AB.`T(.((T$0@XH
MC`5!#C"&!D0..(,'1PY0`Q4!"@XX00XP00XH0@X@0@X80@X00@X(10L4````
MH`$```R-__]>`````$0.$`)5#@@4````N`$``%2-__\J`````$0.$&$."``@
M````T`$``&R-__^U`````$$.$(,"1PZP0`*C"@X01`X(00L0````]`$```B.
M__\%`````````$P````(`@``!([__^\!````0@X0C0)%#AB,`T$.((8$20XH
M@P5'#N`A`F(*#BA!#B!!#AA"#A!"#@A("P*/#N@A2P[P(74.Z"%!#N`A````
M$````%@"``"DC___)0`````````0````;`(``,"/__\:`````````!@```"`
M`@``S(___X@$````1`Y0`S8$"@X(00L8````G`(``$"4__]R`````$0.(&T*
M#@A'"P``%````+@"``"DE/__'0````!$#A!8#@@`3````-`"``"LE/__``$`
M``!"#A",`D$.&(8#20X@@P1$#C`"0@H.($@.&$$.$$(."$L+9`H.($$.&$$.
M$$(."$@+80XX20Y`8`XX00XP``#,````(`,``%R5__^3!P```$(.$(\"0@X8
MC@-"#B"-!$H.*(P%00XPA@9!#CB#!T<.L(,"`W\!#KB#`DX.P(,";`ZX@P)"
M#K"#`@)V"@XX1`XP00XH0@X@0@X80@X00@X(20L#8@$.N(,"1P[`@P)?#KB#
M`D$.L(,"70ZX@P)(#L"#`D\.R(,"30[0@P)+#K"#`@,!`0H..$0.,$$.*$(.
M($(.&$(.$$(."$T+`QH!#KB#`D(.P(,"90ZX@P)!#K"#`@+N"@ZX@P))#L"#
M`D4+*````/`#```LG/__BP(```!"#A"-`D(.&(P#1`XP`\D!"@X80@X00@X(
M2PM`````'`0``)">__\D`0```$(.$(P"00X8A@-$#B"#!$0.,`)^"@X@00X8
M00X00@X(0PMR"@X@1`X800X00@X(1PL``"````!@!```O(#___\!````0@X0
MC`)$#D`#E@$*#A!%#@A!"TP```"$!```6)___QP6````0@X0CP)&#AB.`T(.
M((T$0@XHC`5!#C"&!D$..(,'1P[0!0/W%0H..$$.,$$.*$(.($(.&$(.$$(.
M"$$+````%````-0$```HM?__5`````!$#A`"3PX(2````.P$``!PM?__GP$`
M``!"#A"/`D4.&(X#10X@C01"#BB,!40.,(8&10XX@P='#D`"Y0H..$$.,$$.
M*$(.($(.&$(.$$(."$,+`$`````X!0``Q+;___L!````0@X0C@)&#AB-`T(.
M((P$00XHA@5$#C"#!@-*`0H.*$$.($(.&$(.$$(."$@+````````1````'P%
M``"`N/__70````!"#A"/`DD.&(X#10X@C01%#BB,!40.,(8&2`XX@P='#D!J
M#CA!#C!!#BA"#B!"#AA"#A!"#@@`%````,0%``"8N/__`0``````````````
M$````-P%``"0N/__#```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````"@)D```````'`F0````````0``````
M``"V`@````````$`````````Q@(````````!`````````-8"````````#```
M````````($````````T`````````+%U````````9`````````/"]0```````
M&P`````````(`````````!H`````````^+U````````<``````````@`````
M````]?[_;P`````(`T````````4`````````.`I````````&`````````*@#
M0```````"@`````````Q`P````````L`````````&``````````5````````
M`````````````P``````````P$````````(`````````<`4````````4````
M``````<`````````%P`````````(#T````````<`````````>`Y````````(
M`````````)``````````"0`````````8`````````/[__V\`````^`U`````
M``#___]O``````(`````````\/__;P````!J#4``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````OD`````````````````````````````V($```````$8@
M0```````5B!```````!F($```````'8@0```````AB!```````"6($``````
M`*8@0```````MB!```````#&($```````-8@0```````YB!```````#V($``
M``````8A0```````%B%````````F(4```````#8A0```````1B%```````!6
M(4```````&8A0```````=B%```````"&(4```````)8A0```````IB%`````
M``"V(4```````,8A0```````UB%```````#F(4```````/8A0```````!B)`
M```````6(D```````"8B0```````-B)```````!&(D```````%8B0```````
M9B)```````!V(D```````(8B0```````EB)```````"F(D```````+8B0```
M````QB)```````#6(D```````.8B0```````]B)````````&(T```````!8C
M0```````)B-````````V(T```````$8C0```````5B-```````!F(T``````
M`'8C0```````AB-```````"6(T```````*8C0```````MB-```````#&(T``
M``````````````````````````#_____`````.!B0```````1T-#.B`H36%G
M96EA(#$P+C(N,2TP+C(P,C`Q,C`U+C$N;6=A."D@,3`N,BXQ(#(P,C`Q,C`U
M`$=#0SH@*$UA9V5I82`Q,"XR+C$M,"XR,#(P,3(Q,BXQ+FUG83@I(#$P+C(N
M,2`R,#(P,3(Q,@``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD
M+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`
M+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````
M````````````````````````````````````````````````````````````
M``````````````L````!`````@````````"H`D```````*@"````````'```
M``````````````````$````````````````````3````!P````(`````````
MQ`)```````#$`@```````"0````````````````````$````````````````
M````)@````<````"`````````.@"0```````Z`(````````@````````````
M````````!````````````````````#0```#V__]O`@`````````(`T``````
M``@#````````H``````````%``````````@````````````````````^````
M"P````(`````````J`-```````"H`P```````)`&````````!@````$````(
M`````````!@`````````1@````,````"`````````#@*0```````.`H`````
M```Q`P```````````````````0```````````````````$X```#___]O`@``
M``````!J#4```````&H-````````C``````````%``````````(`````````
M`@````````!;````_O__;P(`````````^`U```````#X#0```````(``````
M````!@````(````(````````````````````:@````0````"`````````'@.
M0```````>`X```````"0``````````4`````````"``````````8````````
M`'0````$````0@`````````(#T````````@/````````<`4````````%````
M%@````@`````````&`````````!^`````0````8``````````"!`````````
M(````````!<````````````````````$````````````````````>0````$`
M```&`````````"`@0```````("````````"P`P``````````````````$```
M```````0`````````(0````!````!@````````#0(T```````-`C````````
M7#D``````````````````!````````````````````"*`````0````8`````
M````+%U````````L70````````D````````````````````$````````````
M````````D`````$````"``````````!@0````````&````````"`/0``````
M````````````$````````````````````)@````!`````@````````"`G4``
M`````("=````````_`````````````````````0```````````````````"F
M`````0````(`````````@)Y```````"`G@```````"`&````````````````
M```(````````````````````L`````X````#`````````/"]0```````\*T`
M```````(````````````````````"``````````(`````````+P````/````
M`P````````#XO4```````/BM````````"`````````````````````@`````
M````"`````````#(````!@````,``````````+Y`````````K@```````/`!
M````````!@`````````(`````````!``````````T0````$````#````````
M`/"_0```````\*\````````0````````````````````"``````````(````
M`````-8````!`````P``````````P$````````"P````````Z`$`````````
M``````````@`````````"`````````#?`````0````,`````````Z,%`````
M``#HL0```````"`````````````````````(````````````````````Y0``
M``@````#`````````"#"0```````"+(```````"`$```````````````````
M(````````````````````.H````!````,`````````````````````BR````
M````;@````````````````````$``````````0`````````!`````P``````
M``````````````````!VL@```````/,````````````````````!````````
)````````````
